<?xml version = "1.0" encoding = "UTF-8"?>
<xsl:stylesheet version = "1.0" 
				xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" 
				xmlns:xlink = "http://www.w3.org/1999/xlink"> 
	<xsl:output method = "html"/>
	<!-- 
############################################################
-->
	
<!-- The root template sets out the HTML elements of the HTML page 
into which the contents of the underlying XML document will be placed.
  -->
	<xsl:template match = "/"> 
		<html> 
			<head> 
<!-- 
**********************************************************************************
-->
				
<!-- The following transforms the title of the document (i.e., the 
contents of the <documentTitle> element), into the title of the HTML page.
  -->
				<title>
					<xsl:value-of select = "//documentTitle"/>
				</title>
			</head> 
			<!-- 
**********************************************************************************
-->
<!-- This stylesheet contains templates for displaying as HTML the 
contents of the XML GAO court document. The following 
reads the output of various templates into the HTML document in the order 
listed.  Changing the order of the templates changes the order in which 
their output is read into the root template and the order in which they are output.
  -->

			<body style = "margin-left:0.5cm; margin-top:0.5cm; margin-right:0.5cm">
				<xsl:for-each select = "//courtDocument">
						<xsl:apply-templates select = "caseMetadata"/>
					<div style="margin-left:2cm; margin-right:1cm">
						<xsl:apply-templates select = "documentBody"/>
						<xsl:apply-templates select = "signers"/>
					</div>
				</xsl:for-each>
			</body> 
		</html> 
	</xsl:template>
<!-- 
############################################################## 
-->
<!-- This template displays the contents of the <caseMetadata> element in 
the underlying XML document.
 -->
	<xsl:template match = "caseMetadata">
<!-- 
**********************************************************************************
-->
<!-- This creates an <html> <a/> tag from the <link> in the xml document.
 -->
	<a>
	<xsl:attribute name="href">
		<xsl:value-of select="../documentMetadata//link/@xlink:href"/>
	</xsl:attribute>
		<xsl:value-of select = "../documentMetadata//link/@xlink:title"/>
	</a>
		
<!-- This displays the contents of the <agency> element within 
the <caseMetadata> tag. The <agency> element contains information 
about the location, type, and name of the tribunal in which the case has been 
filed.
 -->
		<div style="margin-left:85%; text-align:center;">
			<xsl:value-of select = "agency/agencyName"/>
		</div>
			<hr />
		<div style="width:50%; float:left">
			<xsl:value-of select ="agency/agencyOffice"/><br/>
			<xsl:value-of select="agency//city"/>,&#xa0;
			<xsl:value-of select="agency//state"/>&#xa0;
			<xsl:value-of select="agency//postalCode"/>
		</div>
		<xsl:if test="../documentMetadata/documentStatus[@privacy='redacted']">
			<div style="float:right;width:35%;border-style:solid;border-width:1px">
				<xsl:value-of select="../documentMetadata/documentStatus"/>
			</div>
		</xsl:if>
		<br/>
		<br/>
		<!-- 
********************************************************************************
-->		
<!-- This displays the contents of the <agency> element within 
the <caseMetadata> tag. The <agency> element contains information 
about the location, type, and name of the tribunal in which the case has been 
filed. This also displays the file number and date of the xml document.
 -->
		<div style="margin-left:2cm; margin-right:1cm; margin-top:2cm">
		<div style="font-size:18pt; font-weight:bold; margin-top:0.25cm;">
			<xsl:value-of select="//documentTitle"/>
		</div>
		<p/>
		<table>
		<tr>
		<td><b>Matter of:</b></td>
		<td>
		<xsl:value-of select="caseTitle/party[@partyType='protester']/organization | person"/>
		</td>
		</tr>
		<tr>
		<td><b>File:</b></td>
		<td>
		<xsl:value-of select="fullCaseNumber"/>
		<xsl:if test="relatedCase">
			;&#xa0;<xsl:value-of select="relatedCase/fullCaseNumber"/>
		</xsl:if>
		</td>
		</tr>
		<tr>
		<td><b>Date:</b></td>
		<td>
		<xsl:value-of select="..//dateTimeSigned"/>
		</td>
		</tr>
		</table>
<!-- This displays the names and roles of the attorneys listed in
the <caseTitle/> element.
 -->
		<hr/>
		<xsl:for-each select="caseTitle//attorney">
			<xsl:value-of select="fullName"/>,&#xa0;
		<xsl:choose>
			<xsl:when test="role/roleWith">
				<xsl:value-of select=".//roleWith"/>,&#xa0;
				<xsl:value-of select=".//roleName"/>.<br/>
			</xsl:when>
			<xsl:when test="role/roleName">
				<xsl:value-of select=".//roleName"/>.<br/>
			</xsl:when>
			<xsl:otherwise>
				.<br/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:for-each>		
<!-- This displays the names and roles of the administrative 
officers listed in the <caseTitle/> element.
 -->
		<xsl:if test="agency/administrativeOfficer">
		<xsl:for-each select="agency/administrativeOfficer">
			<xsl:value-of select="fullName"/>,&#xa0;
		<xsl:choose>
			<xsl:when test="role/roleWith">
				<xsl:value-of select=".//roleWith//agencyOffice"/>,&#xa0;
				<xsl:value-of select=".//roleName"/>.<br/>
			</xsl:when>
			<xsl:when test="role/roleName">
				<xsl:value-of select=".//roleName"/>.<br/>
			</xsl:when>
			<xsl:otherwise>
				.<br/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:for-each>
		</xsl:if>
		</div>
	</xsl:template>
	<!-- 
#############################################################
-->
<!-- This template displays the paragraphs and paragraph groups in the
body of the xml court document.
  -->
	<xsl:template match = "documentBody">
		 <xsl:if test = "paragraphGroup">
			<xsl:for-each select = "paragraphGroup">
			<xsl:if test="paragraphGroupTitle | paragraphTitle">
				<hr/>
				<b><xsl:value-of select="paragraphGroupTitle | paragraphTitle"/></b><p/>
			</xsl:if>
				<xsl:choose>
					<xsl:when test = "paragraph">
							<xsl:apply-templates select="paragraph"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

<!-- The following templates display the contents of elements within 
the <paragraph> and <paragraphGroup> elements, including 
various <addIn> elements.
 -->
	<xsl:template match = "paragraphSubgroup1">
		<xsl:if test = "@title='Count'">
			<center>
				<xsl:value-of select = "@title"/>
				<xsl:if test = "@number">&#xa0;<xsl:value-of select = "@number"/>
					<p/>
				</xsl:if>
			</center>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "paragraph">
		<xsl:choose>
		<xsl:when test = "paragraphTitle">
			<center>
				<xsl:value-of select = "paragraphTitle"/>
				<xsl:if test = "@label">
					&#xa0;<xsl:value-of select = "@label"/>
					<p/>
				</xsl:if>
			</center>
			<xsl:apply-templates/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates />
		</xsl:otherwise>
		</xsl:choose>
		<br/>
		<br/>
	</xsl:template>

 	<xsl:template match="footnote"> 
		<span style="display:inline; font-size:8pt; font-weight:bold; vertical-align:super"> 
 			<a><xsl:attribute name="href">#<xsl:value-of select="footnoteNumber"/></xsl:attribute>
				<xsl:value-of select="footnoteNumber"/>
			</a>&#xa0;
		</span>
  	</xsl:template> 

	<xsl:template match = "addIn">
		<xsl:choose>
 		<xsl:when test="@addInType='quotationHeading'"> 
			<blockquote>
				<xsl:apply-templates/>
			</blockquote>
  		</xsl:when> 
		<xsl:when test="@addInType='quotationHeading'">
				<xsl:apply-templates/>&#xa0;
		</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match = "simpleCite">
		<i>
			<xsl:apply-templates/>
		</i>
	</xsl:template>

	<xsl:template match = "keyword">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "phrase">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "literal">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "quotation">
		<blockquote><xsl:apply-templates/></blockquote>
	</xsl:template>

	<xsl:template match = "date[@dateType]">
		<b>
			<xsl:apply-templates/>
		</b>
	</xsl:template>

	<xsl:template match = "phrase[@privacy='redacted']">
		<font color='white'>[<xsl:apply-templates/>]</font>
	</xsl:template>

	<xsl:template match = "list">
		<xsl:for-each select = "listItem">
			<xsl:if test = "@title">
				<p/>
				<b><xsl:value-of select = "@title"/>:</b>&#xa0;&#xa0;</xsl:if>
			<p/>
			<xsl:value-of select = "."/>
		</xsl:for-each>
		<xsl:if test = "list">
			<xsl:for-each select = "list">
				<p/>
				<xsl:if test = "@title or @type">
					<b>
						<xsl:value-of select = "@title"/>&#xa0;<xsl:value-of select = "@type"/>&#xa0;
						<xsl:value-of select = "@label"/>
					</b>
				</xsl:if>
				<table WIDTH = "50%">
					<xsl:for-each select = "listItem">
						<tr>
							<td WIDTH = "50%">&#xa0;&#xa0;
								<b>
									<xsl:value-of select = "@title"/>
								</b>
							</td>
							<td>
								<xsl:value-of select = "."/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
<!-- 
#############################################################
-->
	
<!-- This template displays the contents of the <signers> 
tag in the underlying XML document.
 -->
	<xsl:template match = "signers">
		
<!-- This displays information regarding the signatory element.
  -->
		<xsl:for-each select = "signatory">
			<p/>
			<p/>
				<xsl:value-of select = "administrativeOfficer/fullName"/>,&#xa0;
			<br/>
				<xsl:value-of select = "administrativeOfficer//roleName"/>
			<p/>
			<p/>
		</xsl:for-each>
	<!-- 
*********************************************************************
-->
<!-- This displays information in footnotes at the end of the 
<html> document.  -->

		<xsl:for-each select="../documentBody//paragraph/footnote">
		<p/>
		<a>
		<xsl:attribute name="name">
			<xsl:value-of select="footnoteNumber"/>
		</xsl:attribute>
			<div style="font-size:10pt; font-weight:bold; display:inline; vertical-align:super">
				<xsl:value-of select="footnoteNumber"/>&#xa0;
			</div>
		</a>
				<xsl:value-of select="footnoteBody"/>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>