<?xml version='1.0'?>

<xsl:stylesheet version="1.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:cd="http://www.legalxml.org/ns/courtdocument100.dtd"> 

<xsl:output method="html"/>

<!-- 
##################################################################### 
-->
<!-- #USAGE - The root template sets out the HTML elements of the HTML page 
into which the contents of the underlying XML document will be placed.  -->

<xsl:template match="/"> 

<HTML> 
	<HEAD> 

<!-- 
*********************************************************************
-->
<!-- #USAGE - The following transforms the title of the document (i.e., the 
contents of the <documentTitle> element), into the title of the HTML page.  -->

	<TITLE><xsl:value-of 
select="legal/courtDocument//documentTitle"/></TITLE> 

	</HEAD> 

<!-- 
*********************************************************************
-->

<!-- This stylesheet contains templates for displaying as HTML the 
contents of the child elements of the <courtDocument> element.  The child 
elements essentially are containers that label and hold information 
regarding the basic parts of the underlying pleading or discovery 
document. The following reads the output of these various templates into 
the HTML document in the order listed.  Changing the order of the 
subtemplates changes the order in which their output is read into the 
root template. -->

<BODY STYLE="font-size:10pt; margin-left:10%; margin-top:0.5cm; 
margin-right:10%">

<xsl:apply-templates select="legal//caseMetadata"/>
<xsl:apply-templates select="legal//documentBody"/>
<xsl:apply-templates select="legal//signers"/>
<xsl:apply-templates select="legal//proofOfService"/>
<xsl:apply-templates select="legal//attachedItem"/>
</BODY> 
</HTML> 

</xsl:template>

<!-- 
#################################################################
-->

<!-- This template displays the contents of the <caseMetadata> element in 
the underlying XML document. -->

<xsl:template match="caseMetadata">

<!-- 
*********************************************************************
-->

<!-- #USAGE - This displays the contents of the <court> element 
in the <caseMetadata> tag. The <court> element contains 
information about the address or venue, type, and name of the court in 
which the case has been filed. -->

<CENTER>
	<DIV STYLE="font-weight:bold">
		IN THE&#xa0;<xsl:value-of select="court/courtName"/> 
		<BR></BR>
		&#xa0;<xsl:value-of select="court/courtDistrict"/>
&#xa0;<xsl:value-of select="court/state"/>
		<BR></BR>
		<xsl:value-of select="court/courtDivision"/> 
	</DIV>
</CENTER>

<!-- 
*********************************************************************
-->

<!-- This creates a case caption CSS-type box and table to contain both 
the <caseTitle> box and the <documentTitle> box. Creating a case caption 
"wrapper" box provides for all the contents of the caption to be separated 
from the contents of the document which are in the <documentContent> tag. 
This displays the colors, border, and size of the box around the <party> 
tags in the <caseTitle>. -->

<DIV STYLE="margin-top:0.5cm; background-color:#EAEAEA; font-weight:bold">

<!-- 
*********************************************************************
-->
<!-- #USAGE - This displays the contents of each <party> tag having a 
"partyType" attribute containing the text "Petitioner", "Plaintiff", etc. -->

<TABLE PADDING="10px" WIDTH="100%" BORDER="-1px">
	<TR>
		<TD WIDTH="50%">
		<xsl:for-each select="caseTitle/party[@partyType='Plaintiff']">
			<xsl:for-each select="person | organization">
				<xsl:value-of select="fullName | organizationName"/>,
				<xsl:if test="role[roleName]">
					<xsl:for-each select="role/roleName">
						<xsl:value-of select="."/>&#xa0;
					</xsl:for-each>
				</xsl:if>
				<xsl:if test="role/roleWith">
					<xsl:value-of select="role/roleWith"/>,
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<DIV STYLE="margin-top:0.25cm; margin-left:2.5cm">
		<xsl:value-of select="caseTitle/party[@partyType='Plaintiff']/@partyType"/>,
		</DIV>

		<DIV STYLE="margin-top:0.25cm; margin-bottom:0.25cm; margin-left:1cm">
 			<xsl:value-of select="caseTitle/vs"/>
		</DIV>

		<xsl:for-each select="caseTitle/party[@partyType='Defendant']">
			<xsl:for-each select="person | organization">
				<xsl:value-of select="fullName | organizationName"/>,
				<xsl:if test="roleName">
					&#xa0;<xsl:value-of select="roleName"/>&#xa0;
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<DIV STYLE="margin-top:0.25cm; margin-left:2.5cm">
			<xsl:value-of select="caseTitle/party[@partyType='Defendant']/@partyType"/>.
		</DIV>

		<DIV STYLE="margin-top:0.5cm; margin-bottom:0.5cm">
		<HR />
		</DIV>

		<xsl:for-each select="caseTitle/party[@partyType='Plaintiff-Intervenor']">
			<xsl:for-each select="person | organization">
				<xsl:value-of select="fullName | organizationName"/>,
				<xsl:if test="roleName">
					&#xa0;<xsl:value-of select="roleName"/>&#xa0;
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<DIV STYLE="margin-top:0.25cm; margin-left:2.5cm">
			<xsl:value-of select="caseTitle/party[@partyType='Plaintiff-Intervenor']/@partyType"/>.
		</DIV>

		<DIV STYLE="margin-top:0.25cm; margin-bottom:0.25cm; margin-left:1cm">
 			<xsl:value-of select="caseTitle/vs"/>
		</DIV>

		<xsl:for-each select="caseTitle/party[@partyType='Defendant-Intervenor']">
			<xsl:for-each select="person | organization">
				<xsl:value-of select="fullName | organizationName"/>,
				<xsl:if test="roleName">
					&#xa0;<xsl:value-of select="roleName"/>&#xa0;
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>

		<xsl:if test="caseTitle/party[@partyType='Defendant-Intervenor']">
		<DIV STYLE="margin-top:0.25cm; margin-left:2.5cm">
			Defendant.
		</DIV>
		</xsl:if>

		<DIV STYLE="margin-top:0.5cm; margin-bottom:0.5cm">
		<HR />
		</DIV>

		<xsl:for-each select="relatedCase/caseTitle/party[@partyType='Plaintiff']">
			<xsl:for-each select="person | organization">
				<xsl:value-of select="fullName | organizationName"/>,
				<xsl:if test="roleName">
					&#xa0;<xsl:value-of select="roleName"/>&#xa0;
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<DIV STYLE="margin-top:0.25cm; margin-left:2.5cm">
			<xsl:value-of select="relatedCase/caseTitle/party[@partyType='Plaintiff']/@partyType"/>,
		</DIV>

		<DIV STYLE="margin-top:0.25cm; margin-bottom:0.25cm; margin-left:1cm">
 		<xsl:value-of select="relatedCase/caseTitle/vs"/>
		</DIV>
		
		<xsl:for-each select="relatedCase/caseTitle/party[@partyType='Defendant']">
			<xsl:for-each select="person | organization">
				<xsl:value-of select="fullName | organizationName"/>,
				<xsl:if test="roleName">
					&#xa0;<xsl:value-of select="roleName"/>&#xa0;
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<DIV STYLE="margin-top:0.25cm; margin-left:2.5cm">
			<xsl:value-of select="relatedCase/caseTitle/party[@partyType='Defendant']/@partyType"/>,
		</DIV>
	</TD>
	<TD>
		<DIV STYLE="font-size:10pt; margin-top:1cm; text-align:center">
			<xsl:value-of select="fullCaseNumber"/>
			<xsl:if test="relatedCase">
			<div style="margin-top:20%">
				<xsl:value-of select="relatedCase/fullCaseNumber"/>
			</div>
			</xsl:if>
		</DIV>	</TD>
</TR>
</TABLE>
</DIV>	
	<DIV STYLE="font-size:14pt; font-weight:bold; text-align:center; margin-top:1cm">
		<xsl:value-of select="//documentTitle"/>
	</DIV>

</xsl:template>

<!-- 
#############################################################
-->

<!-- This template displays the paragraphs in the body of the court 
document. -->

<xsl:template match="documentBody">

<BR/><BR/>

<xsl:if test="paragraph">
	<xsl:for-each select="paragraph">

	<xsl:if test="@number">
		<xsl:value-of select="@number"/>.&#xa0;&#xa0;
	</xsl:if>

	<xsl:choose>

		<xsl:when test="Highlight">
			<xsl:apply-templates /><BR/><BR/>
		</xsl:when>
		
		<xsl:otherwise>
			<DIV STYLE="text-indent:1cm; margin-right:2cm">
			<xsl:value-of select="." /><BR/><BR/>
			</DIV>
		</xsl:otherwise>

	</xsl:choose>
	</xsl:for-each>
</xsl:if>

<!-- The following displays the contents of the <dateTimeSigned> 
tag in the underlying XML document. -->

	<DIV STYLE="text-indent:1cm; margin-right:2cm">
		<xsl:value-of select="dateTimeSigned"/>
	</DIV>

</xsl:template>

<!-- 
#####################################################################

-->
<!-- #USAGE - This template displays the contents of the 
<signers> tag in the underlying XML document. -->

<xsl:template match="signers">

<!-- 
*********************************************************************
-->

<!-- This displays information regarding the signature line and each 
judicial officers's name as well as address 
and phone number information for the signer. -->

<DIV STYLE="float:left; width:50%; margin-left:25%; margin-top:1.0cm; text-align:left">
	<xsl:value-of select="signatory/signatureLine"/><BR></BR>

	<xsl:for-each select="signatory/judicialOfficer">
		<B>
		<xsl:if test="fullName">
			<xsl:value-of select="fullName"/><BR/>
		</xsl:if>
		<xsl:if test="lastName">
			<xsl:value-of select="firstName"/>&#xa0;
				<xsl:if test="middleName">
					<xsl:value-of select="middleName"/>&#xa0;
				</xsl:if>
			<xsl:value-of select="lastName"/><BR/>
		</xsl:if>
		</B>
		<xsl:value-of select=".//roleName"/>
	</xsl:for-each>
	<BR/>
	<xsl:for-each select="signatory/judicialOfficer">
		<xsl:for-each select="addressLine">
			<xsl:value-of select="."/><BR></BR>
		</xsl:for-each>
		<xsl:value-of select="city"/>
		<xsl:value-of select="state"/>
		<xsl:value-of select="postalCode"/><BR></BR>
		<xsl:if test="telephone">
			<xsl:value-of select="telephone"/><BR></BR>
		</xsl:if>
		<xsl:if test="fax">
			<xsl:value-of select="fax"/><BR></BR>
		</xsl:if>
		<xsl:if test="email">
			<xsl:value-of select="email"/><BR></BR>
		</xsl:if>
	</xsl:for-each>

	</DIV>
</xsl:template>

<!-- 
*********************************************************************
-->
<!-- This displays information regarding attached items. -->

<xsl:template match="attachedItem">
	<xsl:for-each select="attachedItemContent">
	<P/>
		<xsl:if test="@mimeType='image/gif'">
			<IMG>
				<xsl:attribute name="SRC">
					<xsl:value-of select="@href"/>
				</xsl:attribute>
			</IMG>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
