<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" 
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" version="1.0" indent="yes" />

<xsl:attribute-set name="documentStatus">
  <xsl:attribute name="text-indent">1em</xsl:attribute>
  <xsl:attribute name="space-before">0.6em</xsl:attribute>
  <xsl:attribute name="space-after">0.6em</xsl:attribute>
  <xsl:attribute name="text-align">justify</xsl:attribute>
  <xsl:attribute name="font-size">8pt</xsl:attribute>
  <xsl:attribute name="margin-left">1em</xsl:attribute>
  <xsl:attribute name="font-style">italic</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="caseMetadata">
  <xsl:attribute name="space-before">0.6em</xsl:attribute>
  <xsl:attribute name="space-after">0.6em</xsl:attribute>
  <xsl:attribute name="text-align">justify</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="documentTitle">
  <xsl:attribute name="text-align">center</xsl:attribute>
  <xsl:attribute name="font-size">11pt</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="fullCaseNumber">
  <xsl:attribute name="space-before">0.6em</xsl:attribute>
  <xsl:attribute name="space-after">0.6em</xsl:attribute>
  <xsl:attribute name="text-align">center</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="dateTimeSigned">
  <xsl:attribute name="space-before">0.6em</xsl:attribute>
  <xsl:attribute name="space-after">0.6em</xsl:attribute>
  <xsl:attribute name="text-align">center</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="paragraph">
  <xsl:attribute name="text-indent">1em</xsl:attribute>
  <xsl:attribute name="space-before">0.6em</xsl:attribute>
  <xsl:attribute name="space-after">0.6em</xsl:attribute>
  <xsl:attribute name="text-align">justify</xsl:attribute>
  </xsl:attribute-set>

<xsl:attribute-set name="simpleCite">
  <xsl:attribute name="text-decoration">underline</xsl:attribute>
  <xsl:attribute name="font-weight">bold</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="signers">
  <xsl:attribute name="space-before">0.6em</xsl:attribute>
  <xsl:attribute name="space-after">0.6em</xsl:attribute>
</xsl:attribute-set>

<xsl:template match="courtDocument">
  <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
    <fo:layout-master-set>
      <fo:simple-page-master page-height="297mm" page-width="210mm" 
          margin="5mm 25mm 5mm 25mm" master-name="PageMaster">
        <fo:region-body margin="20mm 0mm 20mm 0mm" column-count="2"/>
      </fo:simple-page-master>
    </fo:layout-master-set>
    <fo:page-sequence master-name="PageMaster">
      <fo:flow flow-name="xsl-region-body">
        <fo:block>
          <xsl:apply-templates select="documentMetadata/documentStatus"/>
        </fo:block>
        <fo:block>
          <xsl:apply-templates select="caseMetadata"/>
        </fo:block>
        <fo:block>
          <xsl:apply-templates select="documentBody"/>
        </fo:block>
        <fo:block>
          <xsl:apply-templates select="signers"/>
        </fo:block>
      </fo:flow>
    </fo:page-sequence>
  </fo:root>
</xsl:template>

<xsl:template match="documentMetadata/documentStatus">
  <fo:block xsl:use-attribute-sets="documentStatus">
   <xsl:apply-templates />
  </fo:block>
</xsl:template>

<xsl:template match="caseMetadata">
  <fo:block text-align="justify" font-weight="bold">
  <xsl:apply-templates select="caseTitle/party[@partyType='Employer']"/>
  <fo:inline font-style="italic">and</fo:inline>
  <xsl:apply-templates select="caseTitle/party[@partyType='Petitioner']"/>
  <fo:inline font-weight="bold">, </fo:inline>
  <xsl:apply-templates select="caseTitle/party[@partyType='Petitioner']/@partyType"/>
  </fo:block>
  <fo:inline space-before="0.6em">
  <xsl:apply-templates select="fullCaseNumber"/>
  </fo:inline>
  <fo:block xsl:use-attribute-sets="dateTimeSigned">
  <xsl:apply-templates select="../documentBody/dateTimeSigned"/>
  </fo:block>
  <fo:block xsl:use-attribute-sets="dateTimeSigned">
  <xsl:apply-templates select="..//documentTitle"/>
  </fo:block>
  <fo:block text-align="center">
    <fo:inline>By</fo:inline>
  <xsl:for-each select="agency/administrativeOfficer/fullName">
   <fo:inline>
    <xsl:value-of select="."/>,
   </fo:inline>
  </xsl:for-each>
  </fo:block>
</xsl:template>

<xsl:template match="documentTitle">
  <fo:block xsl:use-attribute-sets="documentTitle">
  <xsl:apply-templates/>
  </fo:block>
</xsl:template>

<xsl:template match="fullCaseNumber">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="dateTimeSigned">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="documentBody">
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="signers">
  <fo:block xsl:use-attribute-sets="signers">
    <xsl:for-each select="signatory[administrativeOfficer]">
    <fo:block margin-top="1em" margin-left="1.5em">
      <xsl:value-of select="signatureLine"/>
    </fo:block>
    <fo:block margin-left="1.5em">
      <xsl:value-of select="administrativeOfficer/fullName"/>
      <fo:inline>,</fo:inline>
      <fo:inline margin-left="1.5em">
      <xsl:value-of select="administrativeOfficer//roleName"/>
      </fo:inline>
    </fo:block>
    </xsl:for-each>
  </fo:block>
  <xsl:if test="signatory[agency]">
  <fo:block margin-top="1em" font-size="10pt">
  <fo:inline>
  <xsl:value-of select="signatory[agency]/signatureLine"/>
  </fo:inline>
  <fo:inline margin-left="0.5em">
  <xsl:value-of select="signatory/agency/agencyName"/>
  </fo:inline>
  </fo:block>
  </xsl:if>
</xsl:template>

<xsl:template match="paragraph">
  <fo:block xsl:use-attribute-sets="paragraph">
    <xsl:apply-templates />
  </fo:block>
</xsl:template>

<xsl:template match="simpleCite">
  <fo:inline xsl:use-attribute-sets="simpleCite">
    <xsl:apply-templates />
  </fo:inline>
</xsl:template>

</xsl:stylesheet >